@@ -1,14 +1,15 @@
 //#include <stdio.h>
 #include <math.h>
+#include <R.h>
 #include "matrix.h"
 #include <time.h>
 #include <sys/types.h>
                  
-void transsurv(times,Ntimes,designX,nx,px,antpers,start,stop,betaS,Nit,cu,vcu,Iinv,
-Vbeta,detail,sim,antsim,rani,Rvcu,RVbeta,test,testOBS,Ut,simUt,Uit,id,status,
-weighted,ratesim,score,dhatMit,dhatMitiid,retur,loglike,profile,sym,baselinevar,clusters,antclust,biid,gamiid)
-double *designX,*times,*betaS,*start,*stop,*cu,*Vbeta,*RVbeta,*vcu,*Rvcu,*Iinv,*test,*testOBS,*Ut,*simUt,*Uit,*score,*dhatMit,*dhatMitiid,*loglike,*biid,*gamiid;
-int *nx,*px,*antpers,*Ntimes,*Nit,*detail,*sim,*antsim,*rani,*id,*status,*weighted,*ratesim,*retur,*profile,*sym,*baselinevar,*clusters,*antclust;
+void transsurv(double *times,int *Ntimes,double *designX,int *nx,int *px,int *antpers,double *start,double *stop,double *betaS,int *Nit,double *cu,double *vcu,double *Iinv,
+double *Vbeta,int *detail,int *sim,int *antsim,int *rani,double *Rvcu,double *RVbeta,double *test,double *testOBS,double *Ut,double *simUt,double *Uit,int *id,int *status,
+int *weighted,int *ratesim,double *score,double *dhatMit,double *dhatMitiid,int *retur,double *loglike,int *profile,int *sym,int *baselinevar,int *clusters,int *antclust,double *biid,double *gamiid)
+//double *designX,*times,*betaS,*start,*stop,*cu,*Vbeta,*RVbeta,*vcu,*Rvcu,*Iinv,*test,*testOBS,*Ut,*simUt,*Uit,*score,*dhatMit,*dhatMitiid,*loglike,*biid,*gamiid;
+//int *nx,*px,*antpers,*Ntimes,*Nit,*detail,*sim,*antsim,*rani,*id,*status,*weighted,*ratesim,*retur,*profile,*sym,*baselinevar,*clusters,*antclust;
 {
 // {{{  setting up
   matrix *ldesignX,*WX,*ldesignG,*CtVUCt,*A,*AI;
@@ -29,8 +30,8 @@ int *nx,*px,*antpers,*Ntimes,*Nit,*detail,*sim,*antsim,*rani,*id,*status,*weight
   int *cluster=calloc(*antpers,sizeof(int));
   double RR,S0star,time,dummy,ll;
   double S0,tau,random,scale,sumscore;
-  double norm_rand();
-  void GetRNGstate(),PutRNGstate();
+//  double norm_rand();
+//  void GetRNGstate(),PutRNGstate();
 
   pg[0]=1; 
 
@@ -493,7 +494,7 @@ int *nx,*px,*antpers,*Ntimes,*Nit,*detail,*sim,*antsim,*rani,*id,*status,*weight
     tau=times[*Ntimes-1]-times[0];
     for (i=1;i<=*pg;i++) VE(rowZ,i-1)=cu[i*(*Ntimes)+(*Ntimes-1)];
 
-    /* Beregning af OBS teststrrelser */
+    /* Beregning af OBS teststorrelser */
     for (s=1;s<*Ntimes;s++) { time=times[s]-times[0]; 
 
       for (i=1;i<=*pg;i++) {
@@ -515,7 +516,7 @@ int *nx,*px,*antpers,*Ntimes,*Nit,*detail,*sim,*antsim,*rani,*id,*status,*weight
 	else {vec_zeros(rowX); replace_row(Utt,s,rowX);}
       }
       for (k=1;k<=*px;k++) Ut[k*(*Ntimes)+s]=ME(Utt,s,k-1);
-    } /*s=1..Ntimes Beregning af obs teststrrelser */
+    } /*s=1..Ntimes Beregning af obs teststorrelser */
 
 
     for (k=1;k<=*antsim;k++) {
